<?php

// $Id: flvmediaplayer_profiles.inc,v 1.1.2.1 2008/11/06 14:21:51 arthuregg Exp $

/* ************************************************************** */
/* PROFILE FUNCTIONS */
/* ************************************************************** */


/**
 * Creates the profile listing page
 * @param int $pid is a profile id
 * @return string
 */
function flvmediaplayer_admin_profiles ($pid = null) {
  
  // return a profile if it is passed in
  if ($pid) {
    // get config data
    $result = db_fetch_array(db_query('SELECT * FROM {flvmediaplayer_profiles} WHERE pid = %d', $pid));
    drupal_set_title(t('Edit profile: !name', array('!name' => $result['name'])));
    return drupal_get_form('flvmediaplayer_profile_edit_form', $result);
  }
  
  // set title
  drupal_set_title(t('Profile list'));
  
  // get the create form
  $output = drupal_get_form('flvmediaplayer_profile_create_form');
  
  // get existing profiles
  $results = db_query('SELECT pid, name FROM {flvmediaplayer_profiles}');
  while ($result = db_fetch_array($results)) {
    $rows[] = array($result['pid'], l($result['name'], 'admin/settings/flvmediaplayer/profiles/'. $result['pid']));
  }
  $header = array(t('Id'), t('Name'));
  return $output . theme('table', $header, $rows);
}
 

/**
 * form for creating a new profile
 */
function flvmediaplayer_profile_create_form() {
  $form = array();
  $form['create'] = array(
    '#type' => 'fieldset',
    '#title' => t('Create new profile'),    
  );
  $form['create']['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#description' => t('Give your profile a distinct name. Use _ for spaces if you need them.'),
  );
  $form['create']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Create'),
  );
  return $form;
}


/**
 * validates the name on the create
 */
function flvmediaplayer_profile_create_form_validate($form_id, $form_values) {
  if (strstr($form_values['name'], ' ')) {
    form_set_error('name', t('Please do not use spaces in the name.'));
  }
}


/**
 * submits a new profile and returns user to the edit screen
 * @param string $from_id
 *   the form id being passed by drupal
 * @param array $form_values
 *   full drupal form array
 * @return string drupal goto
 */
function flvmediaplayer_profile_create_form_submit($form_id, $form_values) {
  // serialize the data from the form
  $data = serialize($form_values);  
  $type = 'profile';    
  $pid = db_next_id('flvmediaplayer_profiles');
  db_query('INSERT INTO {flvmediaplayer_profiles} (pid, type, name, config) VALUES (%d, "%s", "%s", "%s")', $pid, $type, $form_values['name'], $data);
  drupal_set_message(t('Created your profile !name', array('!name' => $form_values['name'])));
  return 'admin/settings/flvmediaplayer/profiles/'. $pid;
}


/**
 * handles the profile config save/delete
 */
function flvmediaplayer_profile_edit_form($result) {
  // get the data for this profile
  $config = unserialize($result['config']);
  $form = array();
  // create the fieldset
  $form['profiles'][$result['pid']] = array(
    '#type' => 'fieldset',
    '#title' => $result['name'],  
  );
  $form['profiles'][$result['pid']]['name'] = array(
    '#type' => 'textfield',
    '#default_value' => $result['name'],    
    '#description' => t('The name of your configuration'),   
  );
  
  // grab the settings form
  $form['profiles'][$result['pid']][] = flvmdiaplayer_get_player_form($config);

  // set the pid 
  $form['profiles'][$result['pid']]['pid'] = array(
    '#type' => 'hidden',
    '#value' => $result['pid'],
  );
  
  $form['profiles'][$result['pid']]['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );
   
  $form['profiles'][$result['pid']]['delete'] = array(
    '#type' => 'submit',
    '#value' => t('Delete'),
  );

  return $form;
}


/**
 * handles the submit of an individual profile form 
 */
function flvmediaplayer_profile_edit_form_submit($form_id, $form_values) {
  switch ($form_values['op']) {
    case t('Delete'):
      db_query('DELETE FROM {flvmediaplayer_profiles} WHERE pid = %d', $form_values['pid']);
      drupal_set_message(t('Deleted your player profile'));
    break;
    
    case t('Save'):
      $prefix = 'flvmp_';

      foreach ($form_values as $name => $value) {
        if (strstr($name, $prefix)) {         
          $data[str_replace($prefix, '', $name)] = $value;         
        }
      }
      // add the profile name to the configuration
      $data['profile_name'] = $form_values['name'];
      $data = serialize($data);
      db_query('UPDATE {flvmediaplayer_profiles} SET name = "%s", config = "%s" WHERE pid = %d', $form_values['name'], $data, $form_values['pid']);
      // clear any cached profiles
      cache_clear_all('flvmp_config_', 'cache_flvmediaplayer', true);
      // clear cached nodes
      cache_clear_all('flvmp_'. $form_values['name'], 'cache_flvmediaplayer', true);
      drupal_set_message(t('Cleared configuration cache'));
      drupal_set_message(t('Saved your player profile'));     
    break;
    
    default:
    break;
  }
}


/**
 * gets a list of all the config names keyed by pid
 * @param string $return
 *   controls what the key on the array is
 * @return array
 */
function flvmediaplayer_profile_get_configs($return = 'pid') {
  static $profiles;
  // cache the profiles locally
  if (! isset($profiles)) {
    $results = db_query('SELECT name, pid FROM {flvmediaplayer_profiles}');
    while ($result = db_fetch_array($results)) {
      $profiles[$result[$return]] = $result['name'];
    }
  }
  return $profiles; 
}


/**
 * gets the config data for a specific profile, caches locally 
 * @param string $profile_name
 *   accepts a profile name or a PID
 * @return array of config values and data
 */
function flvmediaplayer_profile_get_config($profile_name) {
  static $configurations;
  if (! $configurations[$profile_name]) {
    $result = db_result(db_query('SELECT config FROM {flvmediaplayer_profiles} WHERE name = "%s" OR pid = "%s"', $profile_name, $profile_name));
    $configuration[$profile_name] = unserialize($result);
  }
  return $configuration[$profile_name];
}
